<?php
/***********************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific apmt_locationuage governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Calendar
*  Language     : Español
*  Version      : 5.4.0
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2012-02-28
*  Author       : Joe Bordes JPL TSolucio, S.L.
 ********************************************************************************/

$mod_strings = array (
'LBL_MODULE_NAME'=>'Calendario',
'LBL_MODULE_TITLE'=>'Calendario: Inicio',
'LBL_MODULE_APPOINTMENT'=>'Calendario: Evento',
'LBL_MODULE_APPOINTMENT_DETAIL'=>'Calendario: Detalle de Evento',
'LBL_SAVE'=>'Guardar',
'LBL_RESET'=>'Cancelar',
'LBL_LIST_USER_NAME'=>'Usuario',
'LBL_LIST_NAME'=>'Nombre',
'LBL_CALENDAR_SHARED'=>'Eventos compartidos con',
'LBL_CALENDAR_SHARING'=>'Compartir eventos con',
'LBL_SHARING_OPTION'=>'¿Puede ver mis eventos?',
'LBL_LIST_TOOLS'=>'Herramientas',
'LBL_SETTINGS'=>'Preferencias',
'LBL_CALSETTINGS'=>'Preferencias de Calendario',
'LBL_USE24'=>'Usar formato de 24h.',
'LBL_CALSTART'=>'Comenzar el día de Calendario a las',
'LBL_TIMESETTINGS'=>'Preferencias de Hora',
'LBL_HOLDFOLLOWUP'=>'Mantener seguimiento el dia',
'LBL_CALL' => 'Llamada',
'LBL_MEET' => 'Reunión',
'LBL_APPNT' => 'Evento',
'LBL_NEW_APPNT' => 'Nuevo Evento',
'LBL_NEW_APPNT_INFO' => 'Crear Evento',
'LBL_VIEW_DAY_APPNT_INFO' => 'Ver Eventos para hoy',
'LBL_CHANGE_APPNT' => 'ver o cambiar Eventos para hoy (%s - %s)',

'LBL_DAY' => 'Día',
'LBL_DAY_BUTTON_KEY' => 'D',
'LBL_DAY_BUTTON_TITLE' => 'Día [Alt+D]',
'LBL_DAY1' => 'Lunes',
'LBL_DAY2' => 'Martes',
'LBL_DAY3' => 'Miércoles',
'LBL_DAY4' => 'Jueves',
'LBL_DAY5' => 'Viernes',
'LBL_DAY6' => 'Sábado',
'LBL_DAY0' => 'Domingo',

'LBL_SM_MON' => 'Lun',
'LBL_SM_TUE' => 'Mar',
'LBL_SM_WED' => 'Mie',
'LBL_SM_THU' => 'Jue',
'LBL_SM_FRI' => 'Vie',
'LBL_SM_SAT' => 'Sab',
'LBL_SM_SUN' => 'Dom',

'LBL_DATE_TITLE' => 'Día %d, %A',

'LBL_WEEK' => 'Semana',
'LBL_WEEK_BUTTON_KEY' => 'W',
'LBL_WEEK_BUTTON_TITLE' => 'Semana [Alt+W]',
'LBL_WEEKS' => 'Semana',
'LBL_NEXT_WEEK' => 'Semana Siguiente',
'LBL_LAST_WEEK' => 'Semana Anterior',
'LBL_4WEEKS_BACK' => '4 semanas atrás',
'LBL_4WEEKS_PLUS' => '4 semanas siguientes',
'LBL_RELOAD' => 'Actualizar',


'LBL_APPCREATED_BY' => 'Creado por',
'LBL_AT_DATE_TIME' => 'en',

'LBL_MON' => 'Mes',
'LBL_MON_BUTTON_KEY' => 'M',
'LBL_MON_BUTTON_TITLE' => 'Mes [Alt+M]',
'LBL_PREV_MON' => 'Mes Anterior',
'LBL_NEXT_MON' => 'Mes Siguiente',

'LBL_YEAR_BUTTON_KEY'=>'Y',
'LBL_PREV_YEAR'=>'Año Anterior',
'LBL_NEXT_YEAR' => 'Año Siguiente',

'LBL_APP_LOCATION' => 'Lugar',
'LBL_APP_IGNORE_TIME' => 'ignorar horas',
'LBL_SUBJECT'=>'Asunto:',
'LBL_APP_DESCRIPTION' => 'Descripción',
'LBL_CONTACT'=>'Contacto:',
'LBL_CONTACT_LIST'=>'Lista Contactos:',

'LBL_APP_IGNORE_TIME2' => '(p.e. si el evento no tiene definida<br />una hora concreta)',

'LBL_APP_ERR001' =>'Fecha inválida en campo %s!',
'LBL_APP_ERR002' =>'¡Empieza más tarde que la hora de fin!',
'LBL_APP_ERR003' =>'¡Falta Contacto !',
'LBL_APP_ERR004' =>'¡Falta Asunto!',
'ERR_DELETE_RECORD'=>'Debe especificar un registro para eliminar la cuenta.',
'DELETE_CONFIRMATION'=>'¿Borrar el Evento?',

'AppLoc'=> Array('0' => 'Oficina'
			, '1' => 'Fuera'
			, '2' => 'Vacaciones'
			, '3' => 'Enfermo'
			, '4' => 'Pospuesto'
			, '5' => 'Optativo'
			, '6' => 'Privado'),

'cal_month_long'=>array(
"",
"Enero",
"Febrero",
"Marzo",
"Abril",
"Mayo",
"Junio",
"Julio",
"Agosto",
"Septiembre",
"Octubre",
"Noviembre",
"Deciembre",
),

'cal_weekdays_short'=>array(
"Lun",
"Mar",
"Mie",
"Jue",
"Vie",
"Sab",
"Dom",
),
'cal_weekdays_long'=>array(
"Lunes",
"Martes",
"Miércoles",
"Jueves",
"Viernes",
"Sabado",
"Domingo",
),
'cal_month_short'=>array(
"",
"Ene",
"Feb",
"Mar",
"Abr",
"May",
"Jun",
"Jul",
"Ago",
"Sep",
"Oct",
"Nov",
"Dic",
),

'LBL_TIME'=>'Horario',
'LBL_START_TIME' => 'Hora de inicio',
'LBL_END_TIME' => 'Hora de fin',
'LBL_START_DATE'=>'Fecha de inicio',
'LBL_TIME_START'=>'Hora de inicio',//START_TIME cambiada la etiqueta
'LBL_DUE_DATE'=>'Fecha de fin',
'LBL_START_DATE_TIME'=>'Fecha y Hora de inicio',
'LBL_END_DATE_TIME'=>'Fecha y Hora de fin',
'LBL_TODO'=>'Tarea',
'LBL_TODOS'=>'Tareas',
'LBL_EVENTS'=>'Eventos',
'LBL_TOTALEVENTS'=>'Total Eventos :',
'LBL_TOTALTODOS'=>'Total Tareas :',
'LBL_VIEW'=>'Vista',
'LBL_LISTVIEW'=>'Vista de Lista',
'LBL_HRVIEW'=>'Vista de Horas',
'LBL_WEEKVIEW'=>'Vista Semanal',
'LBL_MONTHVIEW'=>'Vista Mensual',
'LBL_YEARVIEW'=>'Vista Anual',
'LBL_STATUS'=>'Situación',
'LBL_ACTION'=>'Acciones',
'LBL_ADD'=>'Añadir',
'LBL_OPENCAL'=>'Abrir Calendario',


'LBL_ADD_EVENT'=>'Añadir Evento',
'LBL_ADDCALL'=>'Añadir Llamada',
'LBL_ADDMEETING'=>'Añadir Reunión',
'LBL_ADDTODO'=>'Añadir Tarea',
'LBL_BEFOREEVENT'=>'antes que comience el evento',
'LBL_BEFORETASK'=>'antes que comience la tarea',
'LBL_EVENTDETAILS'=>'Detalles del Evento',
'LBL_CURSTATUS'=>'Situación Actual',
'LBL_ASSINGEDTO'=>'Asignado A',
'LBL_RELATEDTO'=>'Relacionado Con',
'LBL_PENDING'=>'Pendiente',
'LBL_PUBLIC'=>'Público (Lo verán todos los usuarios)',
'LBL_MORE'=>'Más',
'LBL_EDIT'=>'Editar',
'LBL_EVERYDAY'=>'Cada día',
'LBL_EVERYWEEK'=>'Cada Semana',
'LBL_EVERYMON'=>'Cada Mes',
'LBL_WEEKS'=>'Semanas',
'LBL_MONTHS'=>'Meses',
'LBL_YEAR'=>'Año',
'LBL_NONE_SCHEDULED'=>'Nada Programado',

'LBL_INVITE_INST1'=>'Para Invitar, seleccione los usuarios desde la lista "Usuarios Disponibles" y pulse "Añadir".',
'LBL_INVITE_SHARE'=>'Para Compartir,selecione Usuario desde "Usuarios Disponibles" y Pulse el botón "Añadir".',
'LBL_INVITE_INST2'=>'Para Eliminar, seleccione los usuarios desde la lista "Usuarios Seleccionados" y pulse "Borrar".',
'LBL_SELUSR_INFO'=>' Los Usuarios seleccionados recibirán un email .',
'LBL_CALSHAREMESSAGE'=>'Compartir mi calendario con los siguientes Usuarios',
'LBL_CALSHARE'=>'Compartición de Calendario',
'LBL_SEL_USERS'=>'Usuarios Seleccionados',
'LBL_AVL_USERS'=>'Usuarios Disponibles',
'LBL_ADD_BUTTON'=>'Añadir',
'LBL_USERS'=>'Usuarios',
'LBL_RMV_BUTTON'=>'Borrar',
'LBL_SDRMD'=>'Enviar Recordatorio a',
'LBL_ENABLE_REPEAT'=>'Activar Repetición',
'LBL_REPEAT_ONCE'=>'Repetir cada',
'LBL_ADD_TODO'=>'Crear Tarea',
'LBL_TODONAME'=>'Tarea',
'LBL_TODODATETIME'=>'Fecha y Hora',





//DON'T CONVERT THESE THEY ARE MAPPINGS - STARTS
'db_last_name' => 'LBL_LIST_LAST_NAME',
'db_first_name' => 'LBL_LIST_FIRST_NAME',
'db_title' => 'LBL_LIST_TITLE',
'db_email1' => 'LBL_LIST_EMAIL_ADDRESS',
'db_email2' => 'LBL_LIST_EMAIL_ADDRESS',
//DON'T CONVERT THESE THEY ARE MAPPINGS -ENDS
'LBL_COMPLETED'=>'Completada',
'LBL_DEFERRED'=>'Retrasar',
'LBL_HELD'=>'Realizada',
'LBL_NOTHELD'=>'Anular',
'LBL_POSTPONE'=>'Posponer',
'LBL_CHANGEOWNER'=>'Cambiar Propietario',
'LBL_DEL'=>'Borrar',

//Added for actvity merge with calendar
'LBL_SEARCH_FORM_TITLE'=>'Buscar Tarea',
'LBL_LIST_FORM_TITLE'=>'Listado de Tareas',
'LBL_NEW_FORM_TITLE'=>'Nueva Tarea',
'LBL_TASK_INFORMATION'=>'Información de Tarea',
'LBL_EVENT_INFORMATION'=>'Información de Evento',
'LBL_CALENDAR_INFORMATION'=>'Información de Calendario',

'LBL_NAME'=>'Asunto:',
'LBL_ACTIVITY_NOTIFICATION'=>'Se te ha asignado una tarea. Estado:',
'LBL_ACTIVITY_INVITATION'=>'Has sido invitado a una tarea. Estado:',
'LBL_DETAILS_STRING'=>'Los detalles son',
'LBL_REGARDS_STRING'=>'Un saludo',
'LBL_CONTACT_NAME'=>'Contacto',
'LBL_OPEN_ACTIVITIES'=>'Tareas Pendientes',
'LBL_ACTIVITY'=>'Tarea:',
'LBL_HISTORY'=>'Histórico',
'LBL_UPCOMING'=>'Tareas Pendientes',
'LBL_TODAY'=>'En el Día ',

'LBL_NEW_TASK_BUTTON_TITLE'=>'Nueva Tarea [Alt+N]',
'LBL_NEW_TASK_BUTTON_KEY'=>'N',
'LBL_NEW_TASK_BUTTON_LABEL'=>'Nueva Tarea',
'LBL_SCHEDULE_MEETING_BUTTON_TITLE'=>'Programar Reunión [Alt+M]',
'LBL_SCHEDULE_MEETING_BUTTON_KEY'=>'M',
'LBL_SCHEDULE_MEETING_BUTTON_LABEL'=>'Programar Reunión',
'LBL_SCHEDULE_CALL_BUTTON_TITLE'=>'Programar Llamada [Alt+C]',
'LBL_SCHEDULE_CALL_BUTTON_KEY'=>'C',
'LBL_SCHEDULE_CALL_BUTTON_LABEL'=>'Programar Llamada',
'LBL_NEW_NOTE_BUTTON_TITLE'=>'Nuevo Documento [Alt+T]',
'LBL_NEW_ATTACH_BUTTON_TITLE'=>'Adjuntar Archivo [Alt+F]',
'LBL_NEW_NOTE_BUTTON_KEY'=>'T',
'LBL_NEW_ATTACH_BUTTON_KEY'=>'F',
'LBL_NEW_NOTE_BUTTON_LABEL'=>'Nuevo Documento',
'LBL_NEW_ATTACH_BUTTON_LABEL'=>'Adjuntar Archivo',
'LBL_TRACK_EMAIL_BUTTON_TITLE'=>'Seguir Email [Alt+K]',
'LBL_TRACK_EMAIL_BUTTON_KEY'=>'K',
'LBL_TRACK_EMAIL_BUTTON_LABEL'=>'Seguir Email',

'LBL_LIST_CLOSE'=>'Cerrado',
'LBL_LIST_STATUS'=>'Estado',
'LBL_LIST_CONTACT'=>'Contacto',
//Added for 4.2 release for Account column support as shown by Fredy
'LBL_LIST_ACCOUNT'=>'Cuenta',
'LBL_LIST_RELATED_TO'=>'Relacionado con',
'LBL_LIST_DUE_DATE'=>'Vencimiento',
'LBL_LIST_DATE'=>'Fecha',
'LBL_LIST_SUBJECT'=>'Asunto',
'LBL_LIST_LAST_MODIFIED'=>'Última Modificación',
'LBL_LIST_RECURRING_TYPE'=>'Tipo de recurrencia',

'ERR_DELETE_RECORD'=>"Debe especificar un registro para eliminar la cuenta.",
'NTC_NONE_SCHEDULED'=>'Nada Programado.',

// Added vtiger_fields for Attachments in Activities/SubPanelView.php
'LBL_ATTACHMENTS'=>'Adjuntos',
'LBL_NEW_ATTACHMENT'=>'Nuevo Adjunto',

//Added vtiger_fields after RC1 - Release
'LBL_ALL'=>'Todo',
'LBL_CALL'=>'Llamada',
'LBL_MEETING'=>'Reunión',
'LBL_TASK'=>'Tarea',

//Added for 4GA Release
'Subject'=>'Asunto',
'Assigned To'=>'Asignado A',
'Start Date & Time'=>'Fecha y Hora de Inicio',
'Time Start'=>'Hora de Inicio',
'Due Date'=>'Fecha de Vencimiento',
'Related To'=>'Relacionado con',
'Contact Name'=>'Contacto',
'Status'=>'Estado',
'Priority'=>'Prioridad',
'Visibility'=>'Visibilidad',
'Send Notification'=>'Enviar notificación',
'Created Time'=>'Creado',
'Modified Time'=>'Modificado',
'Activity Type'=>'Tipo de Tarea',
'Description'=>'Descripción',
'Duration'=>'Duración',
'Duration Minutes'=>'Duración (Minutos)',
'Location'=>'Localización',
'No Time'=>'Sin Hora',
//Added for Send Reminder 4.2 release
'Send Reminder'=>'Enviar Recordatorio',
'LBL_YES'=>'Si',
'LBL_NO'=>'No',
'LBL_DAYS'=>'días',
'LBL_MINUTES'=>'minutos',
'LBL_HOURS'=>'horas',
'LBL_BEFORE_EVENT'=>'antes del evento',
//Added for CustomView 4.2 Release
'Close'=>'Cerrado',
'Start Date'=>'Fecha Inicio',
'Type'=>'Tipo',
'End Date'=>'Fecha Fin',
'Recurrence'=> 'Eventos Recurrentes',
'Recurring Type'=> 'Tipo de Recurrencia',
//Activities - Notification Error
'LBL_NOTIFICATION_ERROR'=>'Error de Correo: Compruebe su servidor de correo saliente en Configuración->Servidor de Correo Saliente o revise si el contacto tiene un email definido',
// Mike Crowe Mod --------------------------------------------------------added for generic search
'LBL_GENERAL_INFORMATION'=>'Información General',

'LBL_EVENTTYPE'=>'Tipo de Tarea',
'LBL_EVENTNAME'=>'Asunto',
'LBL_EVENTSTAT'=>'Hora de Inicio ',
'LBL_EVENTEDAT'=>'Vencimiento',
'LBL_INVITE'=>'Invitar',
'LBL_REPEAT'=>'Repetir',
'LBL_REMINDER'=>'Recordar',
'LBL_SENDREMINDER'=>'Enviar Recordatorio',
'LBL_NOTIFICATION'=>'Notificación',
'LBL_SENDNOTIFICATION'=>'Enviar Notificación',
'LBL_RMD_ON'=>'Recordatorio Activo',
'LBL_REPEATEVENT'=>'Repetir cada ',
'LBL_TIMEDATE'=>'Fecha y Hora de Inicio',
'LBL_HR'=>' Horas',
'LBL_MIN'=>' Mins',
'LBL_EVENT'=>'Evento',
'Daily'=>'Días',
'Weekly'=>'Semanas',
'Monthly'=>'Meses',
'Yearly'=>'Año',
'createdtime'=>'Creado',
'modifiedtime'=>'Modificado',
'first'=>'Primero',
'last'=>'Último',
'High'=>'Alto',
'Medium'=>'Medio',
'Low'=>'Bajo',
'LBL_SELECT'=>'Seleccionar',
'LBL_ALL_EVENTS_TODOS'=>'Tareas',
'First'=>'Primero',
'Last'=>'Último',
'on'=>'en',
'day of the month'=>'día del mes',
'Private'=>'Privado',
'Public'=>'Público',

//Added for existing Picklist entries

'Planned'=>'Planeado',
'Held'=>'Realizada',
'Not Held'=>'Pendiente',
'Completed'=>'Completado',
'Deferred'=>'Retrasado',
'Not Started'=>'No Iniciada',
'In Progress'=>'En Progreso',
'Pending Input'=>'Pendiente de datos',
'LBL_REMAINDER_DAY'=>'días',
'LBL_REMAINDER_HRS'=>'hrs',
'Call'=>'Llamada',
'Meeting'=>'Reunión',

//added to send dates and time in calendar notification/invitation mail.

'Start date and time'=>'Día y hora de inicio',
'End date and time'=>'Día y hora de fin',
//this is for task
'End date'=>'Fecha de fin',
'LBL_SET_DATE'=>'Establecer fecha...',
'Recurrence'=>'Recurrencia',

//added to send invitation mail Subject.
'INVITATION'=>' Invitación ',

// Added/Updated for vtiger CRM 5.0.4
'LBL_YEAR_BUTTON_TITLE'=>'Año [Alt+Y]',
'LBL_SELECT_CONTACT'=>'Seleccionar Contacto',
'SHARED_EVENT_DEL_MSG'=>'El Usuario no está autorizado para borrar este registro.',
//added to fix ticket#4525
'LBL_CREATED'=>'creado',
'LBL_UPDATED'=>'actualizado',

//Added after 5.0.4 GA
'LBL_BUSY' => 'Trabajando',

//Custom Fields support for Calendar
'LBL_CUSTOM_INFORMATION'=>'Información Personalizada',

// Repeat Event support for Calendar
'LBL_UNTIL' => 'Hasta',
'LBL_SET_DATE'=>'Establecer Fecha',

'LBL_MINE' =>'Mios',
'LBL_SUCCESS_CALENDAR_1' => 'No. de Tareas Importadas Correctamente : ',
'LBL_SKIPPED_CALENDAR_1' => 'No. de Tareas No Importadas al faltar uno o más campos requeridos : ',
'LBL_SUCCESS_EVENTS_1' => 'No. de Eventos Importados Correctamente : ',
'LBL_SKIPPED_EVENTS_1' => 'No. de Eventos No Importados al faltar uno o más campos requeridos : ',
'LBL_FINISHED'=>'Terminado',
'LBL_UNDO_LAST_IMPORT'=>'Deshacer Ultima Importación',
'LBL_LAST_IMPORT'=>'Ultimos Importados',
'LBL_LAST_IMPORT_UNDONE'=>'Se ha deshecho la última importación',
'LBL_SUCCESS'=>'Correcto!',
'LBL_NO_IMPORT_TO_UNDO'=>'No hay importación para deshacer.',
'LBL_FAILURE'=>'Fallido!',

'LBL_ARE_YOU_SURE'=>'¿Estás seguro?',
'Calendar ID' => 'Id Calendario',
);

?>
